@@ -1,8 +1,13 @@
+use strict;
+use warnings;
+
 use Term::Vspark qw[ show_labeled_graph ];
 
-our $VERSION = '0.21'; # VERSION
+our $VERSION = '0.25'; # VERSION
 # PODNAME: show_labeled_graph
 
+binmode STDOUT, ':encoding(UTF-8)';
+
 chomp( @ARGV = <STDIN> ) unless @ARGV;
 my %k_values = @ARGV;
 
